# Command-line Interface

## Usage

```bash
machinable <command> [options]
```

## -v, --version

Prints the machinable version number

## server

::: warning
This feature is currently under development
:::

Launches a server

## vendor

### fetch

Fetch dependencies of the current project